try:
    from wizzi_utils.algorithms.test.test_algorithms import *
except ModuleNotFoundError as e:
    pass
